@@ -2,7 +2,7 @@ import webcolors as wc
 from requests import get, post
 from time import sleep
 
-class wled:
+class WLedController:
     def __init__(self, ip, port="80"):
         self.ip = ip
         self.port = port
@@ -69,11 +69,4 @@ class wled:
             
         post(f"http://{self.ip}/win&R={col[0]}&G={col[1]}&B={col[2]}&FX=1&SX=230")
         sleep(time)
-        post(f"http://{self.ip}/win&R={oldColor[0]}&G={oldColor[1]}&B={oldColor[2]}&FX={index}&SX={oldSpeed}")
-        
-        
-            
-    
-if __name__ == '__main__':
-    wled = wled('192.168.1.180')
-    wled.blink("green")
\ No newline at end of file
+        post(f"http://{self.ip}/win&R={oldColor[0]}&G={oldColor[1]}&B={oldColor[2]}&FX={index}&SX={oldSpeed}")
\ No newline at end of file
